<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:output method="xml" doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"/>
  <xsl:variable name="evencolor">#eeeeee</xsl:variable>
  <xsl:variable name="oddcolor">#ffffff</xsl:variable>

  <xsl:variable name="uspsdoc" select="document('usps.xml')"/>
  <xsl:variable name="title" select="/ushousemembers/metadata/congress"/>
  <xsl:variable name="date" select="/ushousemembers/metadata/date"/>

  <xsl:key name="membersbystate" match="member" use="state"/>
  <xsl:key name="membersbyparty" match="member" use="party"/>
  <xsl:key name="membersbydistrict" match="member" use="district"/>

  <xsl:template match="/">
    <html>
      <head>
	<title>
          <xsl:value-of select="$title"/>
          <xsl:text>, </xsl:text>
          <xsl:value-of select="$date"/>
	</title>
        <style type="text/css">
          tr.evenrow {background-color: #eeeeee;}
          tr.oddrow {background-color: #ccccff;}
          body {font-family: Arial, Helvetica, sans-serif;}
        </style>
      </head>
      <body>
        <h1>
          <xsl:value-of select="$title"/>
          <xsl:text>, </xsl:text>
          <xsl:value-of select="$date"/>
        </h1>

        <xsl:for-each select="/ushousemembers/member[generate-id() = generate-id(key('membersbystate',state)[1])]">
          <xsl:sort select="$uspsdoc/usps/state[@abbreviation = current()/state]/@name"/>            
          <xsl:variable name="state" select="state/text()"/>
          <h2>
            <xsl:value-of select="$uspsdoc/usps/state[@abbreviation = $state]/@name"/>
          </h2>
          
          <table width="100%">
            <tr>
              <th>Official Name</th>
              <th>State</th>
              <th>Hometown</th>
              <th>District</th>
              <th>Party</th>
            </tr>
            <xsl:for-each select="key('membersbystate',state)">
              <xsl:sort select="official-name"/>
              <xsl:variable name="pos">
                <xsl:value-of select="position()"/>
              </xsl:variable>
              <xsl:apply-templates select=".">
                <xsl:with-param name="pos">
                  <xsl:value-of select="$pos"/>
                </xsl:with-param>
              </xsl:apply-templates>
            </xsl:for-each>
          </table>              
        </xsl:for-each>
      </body>
    </html>
  </xsl:template>
  <xsl:template match="member">
    <xsl:param name="pos"/>
    <xsl:variable name="state"><xsl:value-of select="state"/></xsl:variable>
    <tr>
      <xsl:choose>
        <xsl:when test="$pos mod 2">
          <xsl:attribute name="class"><xsl:value-of select="'oddrow'"/></xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class"><xsl:value-of select="'evenrow'"/></xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td>
        <xsl:value-of select="official-name"/>
      </td>
      <td>
        <xsl:value-of select="$uspsdoc/usps/state[@abbreviation = $state]/@name"/>
      </td>
      <td>
        <xsl:value-of select="hometown"/>
      </td>
      <td>
        <xsl:value-of select="district"/>
      </td>        
      <td>
        <xsl:value-of select="party"/>
      </td>
    </tr>
  </xsl:template>
</xsl:stylesheet>
