<?xml version="1.0" encoding="utf-8" ?>
<?xml-stylesheet type="text/css" href="chart.css"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:svg="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
	<xsl:output method="xml" doctype-public="-//W3C//DTD SVG 1.0//EN" doctype-system="http://www.w3.org/TR/2001/REC-SVG-20010904/DTD/svg10.dtd" encoding="UTF-8" indent="yes"/>
	 
	<xsl:param name="between"     select="5"/>
	<xsl:param name="barWidth"    select="25"/>
	<xsl:param name="graphHeight" select="200"/>
	
	<!-- for calculating the height-->
	<xsl:variable name="maxHeight"> 
		<xsl:for-each select="/course/question/data/@number">
			<xsl:sort select="." data-type="number"/>
			<xsl:if test="position()=last()">
				<xsl:value-of select="."/>
			</xsl:if>
		</xsl:for-each>
	</xsl:variable>
	
	<!-- modifier by which to increment bar graphic -->
	<xsl:variable name="incrementBy" select="$graphHeight div $maxHeight"/>
	
	
		
	<xsl:template match="/">
		
		<svg width="400" height="400" xmlns:xlink="http://www.w3.org/1999/xlink">
		
			<defs>
				<style type="text/css">
					<![CDATA[
					.axes {
						stroke: black;
						stroke-width: 2px;
					}
						
					.title {
						font-family: arial,helvetica,sans-serif;
						font-weight: bold;
						text-anchor: middle;
						font-size: 14pt;
					}
					
					.barnr {
						stroke: black;
						stroke-width: 1px;
						fill: #999933;
					}
					.bar {
						stroke: black;
						stroke-width: 1px;
						fill: #00ff00;
					}
					.xlabels, .ylabels {
						font-family: arial,helvetica,sans-serif;
						text-anchor: middle;
						font-size: 10pt;
					}
					.datalabels {
						font-family: arial,helvetica,sans-serif;
						text-anchor: middle;
						font-size: 7pt;
						font-style: italic;
					}
					]]>
				</style>
				
				<g id="axes" class="axes">
					<line x1="0" y1="0" y2="0">
						<xsl:attribute name="x2">
							<xsl:value-of select="$graphHeight"/>
						</xsl:attribute>
					</line>
					<line x1="0" y1="0" x2="0">
						<xsl:attribute name="y2">
							<xsl:value-of select="$graphHeight"/>
						</xsl:attribute>
					</line>
				</g>
				
				<xsl:apply-templates select="course/question/data"/>
				
		
				<g id="chart-cartesian">
					<xsl:apply-templates select="course/question/data" mode="xlink"/>
					<use xlink:href="#axes"/>    
				</g>
				
				<g id="chart">
					<use xlink:href="#chart-cartesian" transform="translate(0,200) scale(1,-1)"/>    
				</g>
				
				<g id="title" class="title">    
					<text x="0" y="0">
						<xsl:value-of select="course/title"/>, <xsl:value-of select="course/term"/>
					</text>
					<text x="0" y="20">
						<xsl:value-of select="course/question/label"/>
					</text>
				</g>
				
				<g id="xlabels" class="xlabels">
					<xsl:apply-templates select="course/question/data" mode="dataTxtLabels"/>
				</g>
				
				<g id="datalabels" class="datalabels">
					<xsl:apply-templates select="course/question/data" mode="dataLabels"/>      
				</g>
				
				<g id="ylabels" class="ylabels">
					<text x="0" y="0" transform="rotate(-90)">
						Responses
					</text>
				</g>
				
			</defs>
			
			<use xlink:href="#chart"      x="100" y="100"/>
			<use xlink:href="#title"      x="200" y="40"/>
			<use xlink:href="#xlabels"    x="117" y="315"/>
			<use xlink:href="#ylabels"    x="80"  y="200"/>
			<use xlink:href="#datalabels" x="117" y="95"/>
			
		</svg>
		
	</xsl:template>
	
	<xsl:template match="data">
		
		<g>
			
			<xsl:attribute name="id">
				<xsl:value-of select="@score"/>
		 	</xsl:attribute>
		 	
			<rect>
			
				<xsl:attribute name="x">
					<xsl:value-of select="$between + (position()-1) * ($between + $barWidth)"/>
				</xsl:attribute>
				
				<xsl:attribute name="y">
					<xsl:text>0</xsl:text>
				</xsl:attribute>
				
				<xsl:attribute name="height">
					<xsl:value-of select="$incrementBy * @number"/>
				</xsl:attribute>
				
				<xsl:attribute name="width">
					<xsl:text>25</xsl:text>
				</xsl:attribute>
				
				<xsl:attribute name="class">
					<xsl:choose>
						<xsl:when test="position() = 1">
							<xsl:text>barnr</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>bar</xsl:text>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</rect>
		</g>
		
	</xsl:template>

	<xsl:template match="data" mode="xlink">
		<use xlink:href="#{@score}"/>
	</xsl:template>
	
	<xsl:template match="data" mode="dataTxtLabels">
		<text>
			<xsl:attribute name="x">
				<xsl:value-of select="(position()-1) * ($between + $barWidth)"/>
			</xsl:attribute>
			<xsl:attribute name="y">
				0
			</xsl:attribute>

			<xsl:value-of select="@score"/>
		</text>
	</xsl:template>
	
	<xsl:template match="data" mode="dataLabels">
		<text>
			<xsl:attribute name="x">
				<xsl:value-of select="(position()-1) * ($between + $barWidth)"/>
			</xsl:attribute>
			<xsl:attribute name="y">
				<xsl:value-of select="$graphHeight - $incrementBy * @number"/>
			</xsl:attribute>

			<xsl:value-of select="@number"/>
		</text>
	</xsl:template>
	
</xsl:stylesheet>
