<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" version="1.0">

	<xsl:output method="xml"/>

	<!-- 	<xsl:output method="xml" doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" 
		doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd" indent="yes"/> -->
		
	<xsl:param name="acad_year" select="'2002'"/>
	<xsl:param name="term_id" select="'3'"/>
	
	<!-- Process using Xalan, where vars may be passed in key -->
	<xsl:key name="courseByGroup" match="course[@acad_year=$acad_year and @term_id=$term_id]" use="course_group"/>

	<!-- access external doc. -->
	<xsl:variable name="courseCodeLookup" select="document('courses_codes.xml')"/>
	<xsl:key name="courseCodes" match="course_groups/course_group" use="@code"/>
	
	<xsl:attribute-set name="normal">
		<xsl:attribute name="font-family">Times, serif</xsl:attribute>
		<xsl:attribute name="font-size">12pt</xsl:attribute>
	</xsl:attribute-set>
	
	<xsl:attribute-set name="harvardTitle">
		<xsl:attribute name="font-family">Helvetica, sanserif</xsl:attribute>
		<xsl:attribute name="font-size">18pt</xsl:attribute>
		<xsl:attribute name="font-weight">bold</xsl:attribute>
		<xsl:attribute name="text-align">center</xsl:attribute>
	</xsl:attribute-set>
	
	<xsl:attribute-set name="title">
		<xsl:attribute name="font-family">Helvetica, sanserif</xsl:attribute>
		<xsl:attribute name="font-size">18pt</xsl:attribute>
		<xsl:attribute name="font-weight">bold</xsl:attribute>
		<xsl:attribute name="text-align">center</xsl:attribute>
		<xsl:attribute name="space-after">18pt</xsl:attribute>
		<xsl:attribute name="space-after.conditionality">retain</xsl:attribute>
	</xsl:attribute-set>
	
	<xsl:attribute-set name="tableItem">
		<xsl:attribute name="font-family">Helvetica, sanserif</xsl:attribute>
		<xsl:attribute name="font-size">12pt</xsl:attribute>
	</xsl:attribute-set>
	
	<xsl:attribute-set name="courseTitle">
		<xsl:attribute name="font-family">Helvetica, sanserif</xsl:attribute>
		<xsl:attribute name="font-size">12pt</xsl:attribute>
		<xsl:attribute name="font-weight">bold</xsl:attribute>
	</xsl:attribute-set>
	
	<xsl:attribute-set name="courseProf">
		<xsl:attribute name="font-family">Helvetica, sanserif</xsl:attribute>
		<xsl:attribute name="font-style">italic</xsl:attribute>
		<xsl:attribute name="font-size">10pt</xsl:attribute>
	</xsl:attribute-set>
	
	<xsl:attribute-set name="courseDescript">
		<xsl:attribute name="font-family">Times, serif</xsl:attribute>
		<xsl:attribute name="font-size">9pt</xsl:attribute>
		<xsl:attribute name="space-before">9pt</xsl:attribute>
		<xsl:attribute name="space-before.conditionality">retain</xsl:attribute>
		<xsl:attribute name="space-after">25pt</xsl:attribute>
		<xsl:attribute name="space-after.conditionality">retain</xsl:attribute>
	</xsl:attribute-set>
	


	<xsl:template match="/">
	
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
      
			<fo:layout-master-set>
			
				<!-- fo:layout-master-set defines in its children the page layout: 
				the pagination and layout specifications
				- page-masters: have the role of describing the intended subdivisions 
				of a page and the geometry of these subdivisions 
				In this case there is only a simple-page-master which defines the 
				layout for all pages of the text -->
				
				<!-- layout information -->
				<fo:simple-page-master master-name="simple"
									   page-height="11in" 
										page-width="8.5in"
										margin-top="1.0in" 
									 margin-bottom="1.0in" 
									   margin-left="1in" 
									  margin-right="1in">
					<fo:region-body margin-top="0.25in"/>
					<fo:region-before extent="0.5in"/>
				</fo:simple-page-master>
			
			</fo:layout-master-set>
			
      
			<!-- start page-sequenceP
			here comes the text (contained in flow objects)
			the page-sequence can contain different fo:flows 
			the attribute value of master-name refers to the page layout
			which is to be used to layout the text contained in this
			page-sequence-->
			
			<fo:page-sequence master-reference="simple">
				<!-- fo:static-content for header -->
			
				<fo:static-content flow-name="xsl-region-before">
					<fo:block font-size="8pt" text-align="end" xsl:use-attribute-sets="normal">
						Harvard University
						<xsl:choose>
							<xsl:when test="$term_id='1'">
								Extension School Spring Semester
							</xsl:when>
							<xsl:when test="$term_id='2'">
								Extension School Fall Semester
							</xsl:when>
							<xsl:otherwise>
								Summer School
							</xsl:otherwise>
						</xsl:choose>
						Courses <xsl:value-of select="$acad_year"/>
						<xsl:text>, Page </xsl:text>
						<fo:page-number/> of <fo:page-number-citation ref-id="EndOfDoc"/>
					</fo:block>
				</fo:static-content>
             
				<fo:flow flow-name="xsl-region-body">
				
					<fo:block>
						<fo:block xsl:use-attribute-sets="harvardTitle">
							Harvard University
						</fo:block>
						<fo:block xsl:use-attribute-sets="title">
							<xsl:choose>
								<xsl:when test="$term_id='1'">
									Extension School Spring Semester
								</xsl:when>
								<xsl:when test="$term_id='2'">
									Extension School Fall Semester
								</xsl:when>
								<xsl:otherwise>
									Summer School
								</xsl:otherwise>
							</xsl:choose>
							Courses <xsl:value-of select="$acad_year"/>
						</fo:block>
					
						<!-- Table of Contents -->
						<xsl:apply-templates select="//course[generate-id() = generate-id(key('courseByGroup', course_group)[1])]" mode="table">
							<xsl:sort select="document('courses_codes.xml')/courses_codes/course_groups/course_group[@code = current()/course_group]/@name"/>
						</xsl:apply-templates>
						
						<!-- Each course group -->
						<xsl:apply-templates select="//course[generate-id() = generate-id(key('courseByGroup', course_group)[1])]" mode="group">
							<xsl:sort select="course_group"/>
						</xsl:apply-templates>
					
					</fo:block>
					
					<fo:block id="EndOfDoc">
					</fo:block>
					
				</fo:flow>
				<!-- closes the flow element-->
				
			</fo:page-sequence>
			<!-- closes the page-sequence -->
			
		</fo:root>
	
	</xsl:template>
	
	
	<xsl:template match="course" mode="table">

		<!-- set var = course_group code -->
		<xsl:variable name="myCourseGroup" select="course_group"/>
		
		<fo:block text-align-last="justify" xsl:use-attribute-sets="tableItem">

			<fo:basic-link internal-destination="{course_group}">
				<!-- retrieve from external doc/key -->
				<xsl:for-each select="$courseCodeLookup">
					<xsl:value-of select="key('courseCodes', $myCourseGroup)/@name"/>
				</xsl:for-each>
			</fo:basic-link>
			
			<fo:leader leader-pattern="dots"/>
			
			<fo:page-number-citation>
				<xsl:attribute name="ref-id">
					<xsl:value-of select="course_group"/>
				</xsl:attribute>
			</fo:page-number-citation>

		</fo:block>
	</xsl:template>
	
	
	<xsl:template match="course" mode="group">

		<fo:block id="{course_group}" break-before="page" xsl:use-attribute-sets="title">
		
			<!--
			<xsl:attribute name="id">
				<xsl:value-of select="course_group"/>
			</xsl:attribute>
			-->
			
			<!-- set var = course_group code -->
			<xsl:variable name="myCourseGroup" select="course_group"/>
			
			<!-- retrieve from external doc/key -->
			<xsl:for-each select="$courseCodeLookup">
				<xsl:value-of select="key('courseCodes', $myCourseGroup)/@name"/>
			</xsl:for-each>
			
		</fo:block>
		
		<!-- Each course -->
		<xsl:apply-templates select="key('courseByGroup', course_group)">
			<xsl:sort select="title"/>
		</xsl:apply-templates>
       	
	</xsl:template>
	
	
	<xsl:template match="course">
	
		<fo:block xsl:use-attribute-sets="courseTitle">
			<xsl:value-of select="course_group"/><xsl:text>  </xsl:text><xsl:value-of select="course_num"/>.
			<xsl:value-of select="title"/>
			(CRN: <xsl:value-of select="@crn"/>)
		</fo:block>
	
		<xsl:apply-templates select="course_head/person"/>
		
		<fo:block xsl:use-attribute-sets="courseDescript">
			<xsl:value-of select="description"/>
		</fo:block>
		
	</xsl:template>
	
	
	<xsl:template match="person">
	
		<fo:block xsl:use-attribute-sets="courseProf">
			<xsl:value-of select="person_name"/>
			<xsl:text> </xsl:text>
			<xsl:value-of select="person_title"/>
		</fo:block>
		
	</xsl:template>
	
</xsl:stylesheet>