<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" version="1.0">

	<xsl:output method="xml"/>

	<xsl:attribute-set name="tableheader">
		<xsl:attribute name="font-family">Times, serif</xsl:attribute>
		<xsl:attribute name="font-size">12pt</xsl:attribute>
		<xsl:attribute name="font-weight">bold</xsl:attribute>
		<xsl:attribute name="background-color">#dddddd</xsl:attribute>
	</xsl:attribute-set>  
	
	<xsl:variable name="evencolor">#eeeeee</xsl:variable>
	<xsl:variable name="oddcolor">#ffffff</xsl:variable>
	
	<xsl:attribute-set name="normal">
		<xsl:attribute name="font-family">Times, serif</xsl:attribute>
		<xsl:attribute name="font-size">12pt</xsl:attribute>
	</xsl:attribute-set>
	
	<xsl:attribute-set name="title">
		<xsl:attribute name="font-family">Times, serif</xsl:attribute>
		<xsl:attribute name="font-size">18pt</xsl:attribute>
		<xsl:attribute name="font-weight">bold</xsl:attribute>
		<xsl:attribute name="text-align">center</xsl:attribute>
		<xsl:attribute name="padding">0.25em</xsl:attribute>
	</xsl:attribute-set>
	
	<xsl:variable name="title" select="/ushousemembers/metadata/congress"/>
	<xsl:variable name="date" select="/ushousemembers/metadata/date"/>
	<xsl:key name="membersbystate" match="member" use="state"/>

	<xsl:template match="/">
	
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
      
			<fo:layout-master-set>
			
				<!-- fo:layout-master-set defines in its children the page layout: 
				the pagination and layout specifications
				- page-masters: have the role of describing the intended subdivisions 
				of a page and the geometry of these subdivisions 
				In this case there is only a simple-page-master which defines the 
				layout for all pages of the text -->
				
				<!-- layout information -->
				<fo:simple-page-master master-name="simple"
									   page-height="11in" 
										page-width="8.5in"
										margin-top="1.0in" 
									 margin-bottom="1.0in" 
									   margin-left="1in" 
									  margin-right="1in">
					<fo:region-body margin-top="0.25in"/>
					<fo:region-before extent="0.5in"/>
				</fo:simple-page-master>
			
			</fo:layout-master-set>
			<!-- end: defines page layout -->
      
			<!-- start page-sequence
			here comes the text (contained in flow objects)
			the page-sequence can contain different fo:flows 
			the attribute value of master-name refers to the page layout
			which is to be used to layout the text contained in this
			page-sequence-->
			
			<fo:page-sequence master-reference="simple">
				<!-- fo:static-content for header -->
			
				<fo:static-content flow-name="xsl-region-before">
					<fo:block font-size="8pt" text-align="end" xsl:use-attribute-sets="normal">
						<xsl:value-of select="$title"/>
						<xsl:text>, </xsl:text>
						<xsl:value-of select="$date"/>
						<xsl:text>, Page </xsl:text>
						<fo:page-number/> of <fo:page-number-citation ref-id="EndOfDoc"/>
					</fo:block>
				</fo:static-content>
				
				<!-- start fo:flow
				 each flow is targeted 
				 at one (and only one) of the following:
				 xsl-region-body (usually: normal text)
				 xsl-region-before (usually: header)
				 xsl-region-after  (usually: footer)
				 xsl-region-start  (usually: left margin) 
				 xsl-region-end    (usually: right margin)
				 ['usually' applies here to languages with left-right and top-down 
				 writing direction like English]
				 in this case there is only one target: xsl-region-body -->
             
				<fo:flow flow-name="xsl-region-body">
					<fo:block>
						<fo:block xsl:use-attribute-sets="title">
						  <xsl:value-of select="$title"/>
						</fo:block>
						<fo:block xsl:use-attribute-sets="title">
						  <xsl:value-of select="$date"/>
						</fo:block>
					
						<!-- Table of Contents -->
						<xsl:for-each select="/ushousemembers/member[generate-id() = generate-id(key('membersbystate',state)[1])]">
							<xsl:sort select="document('usps.xml')/usps/state[@abbreviation = current()/state]/@name"/>            
							<xsl:variable name="state" select="state/text()"/>
							<fo:block  text-align-last="justify" xsl:use-attribute-sets="normal">
								<xsl:value-of select="document('usps.xml')/usps/state[@abbreviation = $state]/@name"/>
								<fo:leader leader-pattern="dots"/>
								
								<fo:page-number-citation>
									<xsl:attribute name="ref-id">
									 	<xsl:value-of select="generate-id()"/>
									</xsl:attribute>
								</fo:page-number-citation>
								
							</fo:block>                  
						</xsl:for-each>
					
						<!-- each paragraph is encapsulated in a block element
						the attributes of the block define font-family and size, line-heigth etc. -->
						
						<xsl:for-each select="/ushousemembers/member[generate-id() = generate-id(key('membersbystate',state)[1])]">
							<xsl:sort select="document('usps.xml')/usps/state[@abbreviation = current()/state]/@name"/>            
							<xsl:variable name="state" select="state/text()"/>
							
							<fo:block break-before="page" xsl:use-attribute-sets="title">
								<xsl:attribute name="id">
									<xsl:value-of select="generate-id()"/>
								</xsl:attribute>
								<xsl:value-of select="document('usps.xml')/usps/state[@abbreviation = $state]/@name"/>            
							</fo:block>
							
							<fo:table border-style="solid" border-width="0.5pt" border-color="#dddddd" table-layout="fixed">
								<fo:table-column column-width="2.5in"/>
								<fo:table-column column-width="1.25in"/>
								<fo:table-column column-width="1.5in"/>
								<fo:table-column column-width="1.25in"/>
								<fo:table-header xsl:use-attribute-sets="tableheader">
									<fo:table-row>
										<fo:table-cell>
											<fo:block>
												Official Name
											</fo:block>
										</fo:table-cell>
										<fo:table-cell>
											<fo:block>
												District
											</fo:block>
										</fo:table-cell>
										<fo:table-cell>
											<fo:block>
												Hometown
											</fo:block>
										</fo:table-cell>
										<fo:table-cell>
											<fo:block>
												Party
											</fo:block>
										</fo:table-cell>
									</fo:table-row>
								</fo:table-header>
								
								<fo:table-body>
									<xsl:for-each select="key('membersbystate',state)">
										<xsl:sort select="official-name"/>
										<xsl:variable name="pos">
											<xsl:value-of select="position()"/>
										</xsl:variable>
										<xsl:apply-templates select=".">
											<xsl:with-param name="pos">
												<xsl:value-of select="$pos"/>
											</xsl:with-param>
										</xsl:apply-templates>
									</xsl:for-each>
								</fo:table-body>
							</fo:table>
						</xsl:for-each>
					</fo:block>
					
					<fo:block id="EndOfDoc">
					</fo:block>
					
				</fo:flow>
				<!-- closes the flow element-->
				
			</fo:page-sequence>
			<!-- closes the page-sequence -->
			
		</fo:root>
	
	</xsl:template>
  
	<xsl:template match="member">
		<xsl:param name="pos"/>
		<fo:table-row>
			<xsl:choose>
				<xsl:when test="$pos mod 2">
					<xsl:attribute name="background-color">
						<xsl:value-of select="$oddcolor"/>
					</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="background-color">
						<xsl:value-of select="$evencolor"/>
					</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			
			<fo:table-cell>
				<fo:block xsl:use-attribute-sets="normal">
					<xsl:value-of select="official-name"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block xsl:use-attribute-sets="normal">
					<xsl:value-of select="district"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block xsl:use-attribute-sets="normal">
					<xsl:value-of select="hometown"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block xsl:use-attribute-sets="normal">
					<xsl:value-of select="party"/>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
  
</xsl:stylesheet>