<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet 
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"     
  xmlns:redirect="http://xml.apache.org/xalan/redirect"
  extension-element-prefixes="redirect"
  version="1.1">
  <xsl:output method="xml" doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"/>

  <xsl:variable name="uspsdoc" select="document('usps.xml')"/>
  <xsl:key name="membersbystate" match="member" use="state"/>
  <xsl:key name="statecode" match="state" use="@abbreviation"/>
  <xsl:variable name="evencolor">#efefef</xsl:variable>
  <xsl:variable name="oddcolor">#cccccc</xsl:variable>

  <xsl:variable name="title" select="/ushousemembers/metadata/congress"/>
  <xsl:variable name="date" select="/ushousemembers/metadata/date"/>
  <xsl:variable name="displaytitle">
    <xsl:value-of select="$title"/>
    <xsl:text>, </xsl:text>
    <xsl:value-of select="$date"/>
  </xsl:variable>
  <xsl:variable name="style">
    tr.evenrow {background-color: <xsl:value-of select="$evencolor"/>;}
    tr.oddrow {background-color: <xsl:value-of select="$oddcolor"/>;}
    body {font-family: Arial, Helvetica, sans-serif;}
    h1,h2,h3,h4,h5,h6 {text-align: center;}
  </xsl:variable>
  <xsl:template match="/">
    <html>
      <head>
	<title>
          <xsl:value-of select="$displaytitle"/>
	</title>
        <style type="text/css">
          <xsl:value-of select="$style"/>
        </style>
      </head>
      <body>
        <h1>
          <xsl:value-of select="$displaytitle"/>
        </h1>
        <ul>
          <xsl:apply-templates select="/ushousemembers/member[generate-id() = generate-id(key('membersbystate',state)[1])]" mode="statelist">
            <xsl:sort select="document('usps.xml')/usps/state[@abbreviation = current()/state]/@name"/>
          </xsl:apply-templates>
        </ul>
      </body>
    </html>
  </xsl:template>
  <xsl:template match="member" mode="statelist">
            <xsl:message>
              <xsl:value-of select="current()/state"/>
              <xsl:text> </xsl:text>
              <xsl:value-of select="$uspsdoc/usps/state[@abbreviation = current()/state]/@name"/>
            </xsl:message>
    <xsl:variable name="st" select="state"/>
    <li>
      <a href="{concat($st,'.html')}">
        <xsl:for-each select="$uspsdoc">
          <xsl:value-of select="key('statecode',$st)/@name"/>
        </xsl:for-each>
      </a>
    </li>
    
    <xsl:call-template name="writefile">
      <xsl:with-param name="state" select="$st"/>
    </xsl:call-template>
  </xsl:template>
  <xsl:template match="member">
    <tr>
      <xsl:choose>
        <xsl:when test="position() mod 2">
          <xsl:attribute name="class"><xsl:value-of select="'oddrow'"/></xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class"><xsl:value-of select="'evenrow'"/></xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td>
        <xsl:value-of select="official-name"/>
      </td>
      <td>
        <xsl:variable name="st" select="state"/>
        <xsl:for-each select="$uspsdoc">
          <xsl:value-of select="key('statecode',$st)/@name"/>
        </xsl:for-each>
      </td>
      <td>
        <xsl:value-of select="hometown"/>
      </td>
      <td>
        <xsl:value-of select="district"/>
      </td>        
      <td>
        <xsl:value-of select="party"/>
      </td>
    </tr>
  </xsl:template>
  <xsl:template name="writefile">
    <xsl:param name="state"/>
    <xsl:variable name="fullstate" select="$uspsdoc/usps/state[@abbreviation = $state]/@name"/>
    <xsl:document href="concat($state,'.html')">
      <html>
        <head>
          <title>
            <xsl:value-of select="$fullstate"/>
            <xsl:text>:  </xsl:text>
            <xsl:value-of select="$displaytitle"/>
          </title>
          <style type="text/css">
            <xsl:value-of select="$style"/>
          </style>
        </head>
        <body>
          <h1>
            <xsl:value-of select="$displaytitle"/>
          </h1>
          <h2>
            <xsl:value-of select="$fullstate"/>
          </h2>
          <table width="100%">
            <tr>
              <th>Official Name</th>
              <th>State</th>
              <th>Hometown</th>
              <th>District</th>
              <th>Party</th>
            </tr>
            <xsl:apply-templates select="key('membersbystate',state)">
              <xsl:sort select="official-name"/>
            </xsl:apply-templates>
          </table>
        </body>
      </html>
    </xsl:document>
  </xsl:template>
</xsl:stylesheet>
