<?xml version="1.0" encoding="utf-8"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	 
	<xsl:output method="xml" doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" 
		doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd" indent="yes"/>
	
	<xsl:param name="acad_year" select="'2002'"/>
	<xsl:param name="term_id" select="'3'"/>
	
	<!-- Process using Xalan, where vars may be passed in key -->
	<xsl:key name="courseByGroup" match="course[@acad_year=$acad_year and @term_id=$term_id]" use="course_group"/>
	
	<!-- access external doc. -->
	<xsl:variable name="courseCodeLookup" select="document('courses_codes.xml')"/>
	<xsl:key name="courseCodes" match="course_groups/course_group" use="@code"/>
	
	<xsl:template match="/">
		<html>
		
			<head>
				<title>
					Harvard University Summer School Courses 2003
				</title>
				<link href="courses.css" type="text/css" rel="stylesheet"/>
			</head>
			<body>
				<h1>
					<a name="top">
						Harvard University Summer School Courses 2003
					</a>
				</h1>
				
				<div class="toc">
					<ul>
						<xsl:apply-templates select="//course[generate-id() = generate-id(key('courseByGroup', course_group)[1])]" mode="table">
							<xsl:sort select="document('courses_codes.xml')/courses_codes/course_groups/course_group[@code = current()/course_group]/@name"/>
						</xsl:apply-templates>
					</ul>
				</div>
				
				<xsl:apply-templates select="//course[generate-id() = generate-id(key('courseByGroup', course_group)[1])]" mode="group">
					<xsl:sort select="course_group"/>
				</xsl:apply-templates>
				
			</body>
			
		</html>
	</xsl:template>
	
	<xsl:template match="course" mode="table">

		<li>
			<a href="#{course_group}">
				
				<!-- set var = course_group code -->
				<xsl:variable name="myCourseGroup" select="course_group"/>
				
				<!-- retrieve from external doc/key -->
				<xsl:for-each select="$courseCodeLookup">
					<xsl:value-of select="key('courseCodes', $myCourseGroup)/@name"/>
				</xsl:for-each>
				
			</a>
		</li>
		
	</xsl:template>
	
	
	<xsl:template match="course" mode="group">

		<h2>
			<a name="{course_group}">
				
				<!-- set var = course_group code -->
				<xsl:variable name="myCourseGroup" select="course_group"/>
				
				<!-- retrieve from external doc/key -->
				<xsl:for-each select="$courseCodeLookup">
					<xsl:value-of select="key('courseCodes', $myCourseGroup)/@name"/>
				</xsl:for-each>
				
			</a>
		</h2>
		
		<xsl:apply-templates select="key('courseByGroup', course_group)">
			<xsl:sort select="title"/>
		</xsl:apply-templates>
		
		<hr />
        
        <div class="top">
      		[<a href="#top">
        		top
      		</a>]
    	</div>
    	
        <hr />
        
	</xsl:template>
	
	
	<xsl:template match="course">
	
		<div class="course">
			<span class="course_gn">
				<xsl:value-of select="course_group"/><xsl:text>  </xsl:text><xsl:value-of select="course_num"/>.
			</span>
			<span class="title">
				<xsl:value-of select="title"/>
			</span>
			<span class="crn">
				(CRN: <xsl:value-of select="@crn"/>)
			</span>
		</div>
		
		<xsl:apply-templates select="course_head/person"/>
        
	</xsl:template>
	
	<xsl:template match="person">
	
		<div class="course_head">
			<div>
				<span class="course_head_name">
					<xsl:value-of select="person_name"/>
				</span>
				<span class="course_head_title">
					<xsl:value-of select="person_title"/>
				</span>
			</div>
		</div>
		
	</xsl:template>
	
</xsl:stylesheet>