<?xml version="1.0" encoding="utf-8"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	 
	<xsl:output method="xml" doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" 
		doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd" indent="yes"/>
	
	<xsl:param name="acad_year" select="'2002'"/>
	<xsl:param name="term_id" select="'3'"/>
	<xsl:param name="course_group" select="'CSCI'"/>
	
	<!-- Process using Xalan, where vars may be passed in key -->
	<xsl:key name="courseByGroup" match="course[@acad_year=$acad_year and @term_id=$term_id]" use="course_group"/>
	
	<!-- access external doc. -->
	<xsl:variable name="courseCodeLookup" select="document('courses_codes.xml')"/>
	<xsl:key name="courseCodes" match="course_groups/course_group" use="@code"/>
	
	<xsl:template match="/">
		<html>
		
			<head>
				<title>
					Harvard University DCE Courses
				</title>
				<link href="courses.css" type="text/css" rel="stylesheet"/>
			</head>
			<body>
				<h1>
					<a name="top">
						Harvard University 
						
						<xsl:choose>
							<xsl:when test="$term_id='1'">
								Extension School Spring Semester
							</xsl:when>
							<xsl:when test="$term_id='2'">
								Extension School Fall Semester
							</xsl:when>
							<xsl:otherwise>
								Summer School
							</xsl:otherwise>
						</xsl:choose>
						
						<!-- retrieve from external doc/key -->
						<xsl:for-each select="$courseCodeLookup">
							<xsl:value-of select="key('courseCodes', $course_group)/@name"/>
						</xsl:for-each>
						
						Courses <xsl:value-of select="$acad_year"/>
					</a>
				</h1>
				
				<div class="toc">
					<ul>
						
						<xsl:apply-templates select="//course[@acad_year=$acad_year and @term_id=$term_id and course_group=$course_group]" mode="table">
							<xsl:sort select="document('courses_codes.xml')/courses_codes/course_groups/course_group[@code = current()/course_group]/@name"/>
						</xsl:apply-templates>
	
					</ul>
					
					<hr />
					
				</div>
				
				<xsl:apply-templates select="//course[@acad_year=$acad_year and @term_id=$term_id and course_group=$course_group]">
					<xsl:sort select="document('courses_codes.xml')/courses_codes/course_groups/course_group[@code = current()/course_group]/@name"/>
				</xsl:apply-templates>
		
			</body>
			
		</html>
	</xsl:template>
	
	<xsl:template match="course" mode="table">

		<li>
			<a href="#{@crn}">
				<xsl:value-of select="course_group"/>
				<xsl:text> </xsl:text>
				<xsl:value-of select="course_num"/>
				:<xsl:text> </xsl:text>
				<xsl:value-of select="title"/>
			</a>
		</li>
		
	</xsl:template>
	
	
	<xsl:template match="course">
	
		<div class="course">
			<a name="{@crn}">
				<span class="course_gn">
					<xsl:value-of select="course_group"/><xsl:text>  </xsl:text><xsl:value-of select="course_num"/>.
				</span>
				<span class="title">
					<xsl:value-of select="title"/>
				</span>
				<span class="crn">
					(CRN: <xsl:value-of select="@crn"/>)
				</span>
			</a>
		</div>
		
		<xsl:apply-templates select="course_head/person"/>
		
		<div class="description">
			<xsl:value-of select="description"/> 
    	</div>
        	
        <div class="top">
      		[<a href="#top">
        		top
      		</a>]
    	</div>
        
	</xsl:template>
	
	<xsl:template match="person">
	
		<div class="course_head">
			<div>
				<span class="course_head_name">
					<xsl:value-of select="person_name"/>
					<xsl:text> </xsl:text>
				</span>
				<span class="course_head_title">
					<xsl:value-of select="person_title"/>
				</span>
			</div>
		</div>
		
	</xsl:template>
	
</xsl:stylesheet>