<?xml version="1.0" encoding="utf-8"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	 
	<xsl:output method="xml" doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" 
		doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd" indent="yes"/>
	
	<xsl:param name="acad_year" select="'2002'"/>
	<xsl:param name="term_id" select="'3'"/>
	<xsl:param name="course_group" select="'CSCI'"/>
	<xsl:param name="crn" select="'31683'"/>
	
	<!-- access external doc. -->
	<xsl:variable name="courseCodeLookup" select="document('courses_codes.xml')"/>
	<xsl:key name="courseCodes" match="course_groups/course_group" use="@code"/>
	
	<xsl:template match="/">
		<html>
		
			<head>
				<title>
					Harvard University DCE Courses
				</title>
				<link href="courses.css" type="text/css" rel="stylesheet"/>
			</head>
			<body>
				
				<xsl:apply-templates select="//course[@crn=$crn]"/>
		
			</body>
			
		</html>
	</xsl:template>
	
	<xsl:template match="course">
	
		<h1>
			<a name="top">
				Harvard University 
				
				<xsl:choose>
					<xsl:when test="$term_id='1'">
						Extension School Spring Semester
					</xsl:when>
					<xsl:when test="$term_id='2'">
						Extension School Fall Semester
					</xsl:when>
					<xsl:otherwise>
						Summer School
					</xsl:otherwise>
				</xsl:choose>
				
				<!-- set var = course_group code -->
				<xsl:variable name="myCourseGroup" select="course_group"/>
				
				<!-- retrieve from external doc/key -->
				<xsl:for-each select="$courseCodeLookup">
					<xsl:value-of select="key('courseCodes', $myCourseGroup)/@name"/>
				</xsl:for-each>
				
				Course <xsl:value-of select="$acad_year"/>
			</a>
		</h1>
				
		<div class="course">
			<a name="{@crn}">
				<span class="course_gn">
					<xsl:value-of select="course_group"/><xsl:text>  </xsl:text><xsl:value-of select="course_num"/>.
				</span>
				<span class="title">
					<xsl:value-of select="title"/>
				</span>
				<span class="crn">
					(CRN: <xsl:value-of select="@crn"/>)
				</span>
			</a>
		</div>
		
		<xsl:apply-templates select="course_head/person"/>
		
		<div class="description">
			<xsl:value-of select="description"/> 
    	</div>
        
	</xsl:template>
	
	<xsl:template match="person">
	
		<div class="course_head">
			<div>
				<span class="course_head_name">
					<xsl:value-of select="person_name"/>
					<xsl:text> </xsl:text>
				</span>
				<span class="course_head_title">
					<xsl:value-of select="person_title"/>
				</span>
			</div>
		</div>
		
	</xsl:template>
	
</xsl:stylesheet>