<?xml version="1.0" encoding="utf-8"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.1">
	 
	<xsl:output method="xml" doctype-public="-//W3C//DTD XHTML Basic 1.0//EN" 
		doctype-system="http://www.w3.org/TR/xhtml-basic/xhtml-basic10.dtd" indent="yes" />
	
	<xsl:param name="acad_year" select="'2002'"/>
	<xsl:param name="term_id" select="'3'"/>
	
	<!-- '$acad_year' and '$term_it' hardcoded, as saxon refuses vars passed into key -->
	<xsl:key name="viewByInstructor" match="course[@acad_year=2002 and @term_id=3]" use="course_head/person/person_name"/>
	
	<!-- access external doc. -->
	<xsl:variable name="courseCodeLookup" select="document('courses_codes.xml')"/>
	<xsl:key name="courseCodes" match="course_groups/course_group" use="@code"/>
	
	<xsl:template match="/">
		<html>
		
			<head>
				<title>
					 Instructors
				</title>
				<link href="courses.css" type="text/css" rel="stylesheet"/>
			</head>
			<body>
				<div>

					<xsl:copy-of select="document('B_navbarA.html')" />
					
					<table>
						<tr>
							<td>
	
								<h1>
									Instructors
								</h1>
								
								<div class="toc">
									<ul>
										<xsl:apply-templates select="//course[generate-id() = generate-id(key('viewByInstructor', course_head/person/person_name)[1])]" mode="table">
											<xsl:sort select="course_head/person/person_name"/>
										</xsl:apply-templates>
									</ul>
								</div>
												
								<xsl:apply-templates select="//course[generate-id() = generate-id(key('viewByInstructor', course_head/person/person_name)[1])]" mode="Instructor">
									<xsl:sort select="course_head/person/person_name" />
								</xsl:apply-templates>
								
								<div class="WMLbar">
									<a class="WMLbar" href="viewWML.wml">
										. WML .
									</a>
									<a class="WMLbar" href="viewByInstructor.html">
										XML
									</a>
								</div>
								
							</td>
							<xsl:copy-of select="document('B_news/B_news.html')" />
						</tr>
					</table>
				</div>
				
			</body>
			
		</html>
	</xsl:template>
	
	<xsl:template match="course" mode="table">

		<li>
			<xsl:choose>
				<xsl:when test="count(key('viewByInstructor', course_head/person/person_name))=1">
					<a href="viewByCrn/B_{@crn}.html">
						<xsl:value-of select="course_head/person/person_name" />
					</a>
				</xsl:when>
				<xsl:otherwise>
					<a href="viewByInstructor/B_{course_head/person/person_name}.html">
						<xsl:value-of select="course_head/person/person_name" />
					</a>
				</xsl:otherwise>
			</xsl:choose>
		</li>
		
	</xsl:template>
	
	<xsl:template match="course" mode="Instructor">
	
		<xsl:if test="count(key('viewByInstructor', course_head/person/person_name))!=1">
		
			<xsl:variable name="nHtml" select="course_head/person/person_name"/>
			<xsl:document href="viewByInstructor/B_{concat($nHtml,'.html')}">
			
				<html>
					<head>
						<title>
							<xsl:value-of select="course_head/person/person_name"/>
						</title>
						<link rel="stylesheet" type="text/css" href="../courses.css"/>
					</head>
					<body>

						<div>

							<xsl:copy-of select="document('B_navbarB.html')" />
							<table>
								<tr>
									<td>
	
										<h4>
											<xsl:value-of select="course_head/person/person_name"/>
										</h4>
					
										<xsl:apply-templates select="key('viewByInstructor', course_head/person/person_name)">
											<xsl:sort select="course_head/person/person_name" />
										</xsl:apply-templates>
										
										<div class="top">
											<a href="../B_viewByInstructor.html">
												Return to Instructors Listing
											</a>
										</div>
									</td>
									<xsl:copy-of select="document('B_news/B_news.html')" />
								</tr>
							</table>
						</div>
					</body>
				 </html>
			</xsl:document>
		</xsl:if>
	</xsl:template>
	
	
	<xsl:template match="course">
	
		<div class="course">
			<span class="title">
				<a href="../viewByCrn/B_{@crn}.html">
					<xsl:value-of select="title"/>
				</a>
			</span>
			<span class="course_gn">
				<xsl:value-of select="course_group"/><xsl:text>  </xsl:text><xsl:value-of select="course_num"/>.
			</span>
			<span class="crn">
				(CRN: <xsl:value-of select="@crn"/>)
			</span>
		</div>
		
		<xsl:apply-templates select="course_head/person"/>
        
	</xsl:template>
	
	<xsl:template match="person">
	
		<div class="course_head">
			<div>
				<span class="course_head_name">
					<xsl:value-of select="person_name"/>
					<xsl:text> </xsl:text>
				</span>
				<span class="course_head_title">
					<xsl:value-of select="person_title"/>
				</span>
			</div>
		</div>
		
	</xsl:template>
	
</xsl:stylesheet>