<?xml version="1.0" encoding="utf-8"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.1">
	 
	<xsl:output method="xml" doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" 
		doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd" indent="yes" />
	
	<xsl:param name="acad_year" select="'2002'" />
	<xsl:param name="term_id" select="'3'" />
	
	<!-- '$acad_year' and '$term_it' hardcoded, as saxon refuses vars passed into key -->
	<xsl:key name="viewByGroup" match="course[@acad_year=2002 and @term_id=3]" use="course_group" />
	
	<!-- access external doc. -->
	<xsl:variable name="courseCodeLookup" select="document('courses_codes.xml')" />
	<xsl:key name="courseCodes" match="course_groups/course_group" use="@code" />
	
	<xsl:template match="/">
		<html>
		
			<head>
				<title>
					 Subjects
				</title>
				<link href="courses.css" type="text/css" rel="stylesheet" />
			</head>
			<body>
				<div align="center">
					<table  width="640">
						<xsl:copy-of select="document('navbarC.html')" />
						<tr> 
							<td width="400" bgcolor="#ffffff">

								<h1>
									Subjects
								</h1>
								
								<div class="toc">
									<ul>
										<xsl:apply-templates select="//course[generate-id() = generate-id(key('viewByGroup', course_group)[1])]" mode="table">
											<xsl:sort select="document('courses_codes.xml')/courses_codes/course_groups/course_group[@code = current()/course_group]/@name"/>
										</xsl:apply-templates>
									</ul>
								</div>
								
								<xsl:apply-templates select="//course[generate-id() = generate-id(key('viewByGroup', course_group)[1])]" mode="group">
									<xsl:sort select="course_group"/>
								</xsl:apply-templates>

								<a href="pdf/main.pdf">
									<img align="right" src="pdfdoc.gif"  alt="PDF" />
								</a>
								
								<br /> <br /> <br />
								
								<div class="WMLbar">
									<a class="WMLbar" href="viewWML.wml">
										. WML .
									</a>
									<a class="WMLbar" href="B_viewByGroup.html">
										BASIC
									</a>
								</div>
									
							</td>
							<xsl:copy-of select="document('news/news.html')" />
						</tr>
					</table>
				</div>
			</body>
		</html>
	</xsl:template>
	
	<xsl:template match="course" mode="table">

		<li>
			<a href="viewByGroup/{course_group}.html">
				
				<!-- set var = course_group code -->
				<xsl:variable name="myCourseGroup" select="course_group" />
				
				<!-- retrieve from external doc/key -->
				<xsl:for-each select="$courseCodeLookup">
					<xsl:value-of select="key('courseCodes', $myCourseGroup)/@name" />
				</xsl:for-each>
				
			</a>
		</li>
		
	</xsl:template>
	
	
	
	<xsl:template match="course" mode="group">
	
		<xsl:variable name="nHtml" select="course_group" />
		
		<xsl:document href="viewByGroup/{concat($nHtml,'.html')}">
		
			<html>
				<head>
					<title>
						Harvard University Summer School Courses 2003
					</title>
					<link rel="stylesheet" type="text/css" href="../courses.css" />
				</head>
				<body>
					<div align="center">
						<table  width="640">
							<xsl:copy-of select="document('navbarB.html')" />
							<tr> 
								<td width="400" bgcolor="#ffffff">

									<h4>
										<!-- set var = course_group code -->
										<xsl:variable name="myCourseGroup" select="course_group" />
										
										<!-- retrieve from external doc/key -->
										<xsl:for-each select="$courseCodeLookup">
											<xsl:value-of select="key('courseCodes', $myCourseGroup)/@name" />
										</xsl:for-each>
									</h4>
				
									<xsl:apply-templates select="key('viewByGroup', course_group)">
										<xsl:sort select="title"/>
									</xsl:apply-templates>
								
									<br />
									
									<div>
										<a href="../pdf/byGroup/{course_group}.pdf">
											<img align="right" src="../pdfdoc.gif"  alt="PDF" />
										</a>
									</div>
									
									<br /> <br /> <br />
								
									<div class="top">
									
										<hr/>
										
										<a href="../viewByGroup.html">
											Return to Course Group Listing
										</a>
										
										<hr/>
										
									</div>
									
								</td>
								<xsl:copy-of select="document('news/news.html')" />
							</tr>
						</table>
					</div>
			 	</body>
			 </html>
		</xsl:document>
		
	</xsl:template>
	
	<xsl:template match="course">
	
		<div class="course">
			<span class="title">
				<a href="../viewByCrn/{@crn}.html">
					<xsl:value-of select="title" />
				</a>
			</span>
			<span class="course_gn">
				<xsl:value-of select="course_group" />
				<xsl:text>  </xsl:text>
				<xsl:value-of select="course_num" />.
			</span>
			<span class="crn">
				(CRN: <xsl:value-of select="@crn" />)
			</span>
		</div>
		
		<xsl:apply-templates select="course_head/person" />
        
	</xsl:template>
	
	<xsl:template match="person">
	
		<div class="course_head">
			<div>
				<span class="course_head_name">
					<xsl:value-of select="person_name" />
					<xsl:text> </xsl:text>
				</span>
				<span class="course_head_title">
					<xsl:value-of select="person_title" />
				</span>
			</div>
		</div>
		
	</xsl:template>
	
</xsl:stylesheet>