<?xml version="1.0" encoding="utf-8"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.1">
	 
	<xsl:output method="xml" doctype-public="-//W3C//DTD XHTML Basic 1.0//EN" 
		doctype-system="http://www.w3.org/TR/xhtml-basic/xhtml-basic10.dtd" indent="yes" />
	
	<xsl:param name="acad_year" select="'2002'" />
	<xsl:param name="term_id" select="'3'" />
	
	<!-- '$acad_year' and '$term_it' hardcoded, as saxon refuses vars passed into key -->
	<!-- set up 2 keys for courses by day and by time -->
	<xsl:key name="coursesbyday"  match="course[@acad_year=2002 and @term_id=3]" use="meeting/meeting_days" />
	<xsl:key name="coursesbytime" match="course[@acad_year=2002 and @term_id=3]" use="meeting/meeting_begin" />
	
	<!-- variables to hold unique lists of courses by day and time --> 
	<xsl:variable name="unique_days"  select="//course[generate-id() = generate-id(key('coursesbyday', meeting/meeting_days))]" />
	<xsl:variable name="unique_times" select="//course[generate-id() = generate-id(key('coursesbytime', meeting/meeting_begin))]" />

	<!-- access external doc. -->
	<xsl:variable name="meetingCodeLookup" select="document('meeting_codes.xml')" />
	<xsl:key name="meetingCodes" match="meeting_group/meeting_days" use="@code" />

	<xsl:template match="/">
		<html>
		
			<head>
				<title>
					Day and Time
				</title>
				<link href="courses.css" type="text/css" rel="stylesheet" />
			</head>
			<body>
				<div>

					<xsl:copy-of select="document('B_navbarA.html')" />
					
					<table>
						<tr>
							<td>
								<h1>
									Day and Time
								</h1>
								
								<div class="toc">
									<ul>
										<!-- loop first through days --> 
										<xsl:for-each select="$unique_days">
											<xsl:sort select="meeting/meeting_days" />
											
											<!-- create a variable to store the courses on this day -->
											<xsl:variable name="day" select="key('coursesbyday',meeting/meeting_days)" />
											
											<xsl:if test="meeting/meeting_days!=''">
												<li>
													<!-- output the day label -->
													<xsl:variable name="mMeetingDays" select="meeting/meeting_days" />
													
													<!-- retrieve from external doc/key -->
													<xsl:for-each select="$meetingCodeLookup">
														<xsl:value-of select="key('meetingCodes', $mMeetingDays)/@name" />
													</xsl:for-each>
												
													<ul>
														<!-- loop through times -->
														<xsl:for-each select="$unique_times">
															<xsl:sort select="meeting/meeting_begin" data-type="number" />
													
															<!-- create a variable to store courses at this time -->
															<xsl:variable name="time" select="key('coursesbytime', meeting/meeting_begin)" />
													
															<!-- take the first element of the intersection, Generate Table -->
															<xsl:apply-templates select="$day[count($time | .) = count($time)][1]" mode="table" />
																					
															<!-- Generate Doc -->
															<xsl:apply-templates select="$day[count($time | .) = count($time)][1]" mode="days" />
															
														</xsl:for-each>
													</ul>
												
												</li>
											</xsl:if>
										</xsl:for-each>
									</ul>
								</div>
								
								<div class="WMLbar">
									<a class="WMLbar" href="viewWML.wml">
										. WML .
									</a>
									<a class="WMLbar" href="viewByDay.html">
										XML
									</a>
								</div>
								
							</td>
							<xsl:copy-of select="document('B_news/B_news.html')" />
						</tr>
					</table>
				</div>
			</body>
			
		</html>
	</xsl:template>
	
	<xsl:template match="course" mode="table">

		<li>
			<a href="viewByDay/B_{meeting/meeting_days}{meeting/meeting_begin}.html">
			
				<xsl:variable name="mTime" select="meeting/meeting_begin" />
				<xsl:variable name="mTimeFx" select="$mTime - 1200" />
				<xsl:choose>
					<xsl:when test="$mTime &gt; 1299">
						<xsl:choose>
							<xsl:when test="$mTimeFx &gt; 999">
								<xsl:value-of select="concat(substring($mTimeFx, 1, 2), ':', substring($mTimeFx, 3, 2))" />pm
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="concat(substring($mTimeFx, 1, 1), ':', substring($mTimeFx, 2, 2))" />pm
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:choose>
							<xsl:when test="$mTime &gt; 999">
								<xsl:value-of select="concat(substring($mTime, 1, 2), ':', substring($mTime, 3, 2))" />am
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="concat(substring($mTime, 1, 1), ':', substring($mTime, 2, 2))" />am
							</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
				
			</a>					
		</li>
		
	</xsl:template>
	
	
	<xsl:template match="course" mode="days">
	
		<xsl:variable name="firstHalf"  select="meeting/meeting_days" />
		<xsl:variable name="secondHalf" select="meeting/meeting_begin" />
		
		<xsl:document href="viewByDay/B_{concat($firstHalf, $secondHalf,'.html')}">
		
			<html>
				<head>
					<title>
						<xsl:variable name="mMeetingDays" select="meeting/meeting_days" />
						
						<!-- retrieve from external doc/key -->
						<xsl:for-each select="$meetingCodeLookup">
							<xsl:value-of select="key('meetingCodes', $mMeetingDays)/@name" />
						</xsl:for-each>
					</title>
					<link rel="stylesheet" type="text/css" href="../courses.css" />
				</head>
				<body>
					<div>

						<xsl:copy-of select="document('B_navbarB.html')" />
						<table>
							<tr>
								<td>
	
									<h4>
										<xsl:variable name="mMeetingDays" select="meeting/meeting_days" />
										<!-- retrieve from external doc/key -->
										<xsl:for-each select="$meetingCodeLookup">
											<xsl:value-of select="key('meetingCodes', $mMeetingDays)/@name" />
										</xsl:for-each>
										<xsl:text> </xsl:text>
										
										<xsl:variable name="mTime" select="meeting/meeting_begin" />
										<xsl:variable name="mTimeFx" select="$mTime - 1200" />
										<xsl:choose>
											<xsl:when test="$mTime &gt; 1299">
												<xsl:choose>
													<xsl:when test="$mTimeFx &gt; 999">
														<xsl:value-of select="concat(substring($mTimeFx, 1, 2), ':', substring($mTimeFx, 3, 2))" />pm
													</xsl:when>
													<xsl:otherwise>
														<xsl:value-of select="concat(substring($mTimeFx, 1, 1), ':', substring($mTimeFx, 2, 2))" />pm
													</xsl:otherwise>
												</xsl:choose>
											</xsl:when>
											<xsl:otherwise>
												<xsl:choose>
													<xsl:when test="$mTime &gt; 999">
														<xsl:value-of select="concat(substring($mTime, 1, 2), ':', substring($mTime, 3, 2))" />am
													</xsl:when>
													<xsl:otherwise>
														<xsl:value-of select="concat(substring($mTime, 1, 1), ':', substring($mTime, 2, 2))" />am
													</xsl:otherwise>
												</xsl:choose>
											</xsl:otherwise>
										</xsl:choose>
										
									</h4>
	
									<xsl:apply-templates select="key('coursesbyday', meeting/meeting_days)">
										<xsl:sort select="title"/>
										<xsl:with-param name="startTime" select="meeting/meeting_begin"/>
									</xsl:apply-templates>
									
									<div class="top">
										<a href="../B_viewByDay.html">
											Return to Day and Time Listing
										</a>
									</div>
								</td>
								<xsl:copy-of select="document('B_news/B_news.html')" />
							</tr>
						</table>
					</div>
			 	</body>
			 </html>
		</xsl:document>
		
	</xsl:template>
	
	
	<xsl:template match="course">
		<xsl:param name="startTime" />
		
		<xsl:if test="meeting/meeting_begin=$startTime">
		
			<div class="course">
				<span class="title">
					<a href="../viewByCrn/B_{@crn}.html">
						<xsl:value-of select="title" />
					</a>
				</span>
				<span class="course_gn">
					<xsl:value-of select="course_group"/><xsl:text>  </xsl:text><xsl:value-of select="course_num" />.
				</span>
				<span class="crn">
					(CRN: <xsl:value-of select="@crn" />)
				</span>
			</div>
			
			<xsl:apply-templates select="course_head/person" />
			
		</xsl:if>
		
	</xsl:template>
		
	<xsl:template match="person">
	
		<div class="course_head">
			<div>
				<span class="course_head_name">
					<xsl:value-of select="person_name" />
					<xsl:text> </xsl:text>
				</span>
				<span class="course_head_title">
					<xsl:value-of select="person_title" />
				</span>
			</div>
		</div>
	</xsl:template>

	
</xsl:stylesheet>