<?xml version="1.0" encoding="utf-8"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.1">
	 
	<xsl:output method="xml" doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" 
		doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd" indent="yes"/>
	
	<xsl:param name="acad_year" select="'2002'"/>
	<xsl:param name="term_id" select="'3'"/>

	<!-- '$acad_year' and '$term_it' hardcoded, as saxon refuses vars passed into key -->
	<xsl:key name="viewByCrn" match="course[@acad_year=2002 and @term_id=3]" use="@crn"/>
	
	<!-- access external doc. -->
	<xsl:variable name="meetingCodeLookup" select="document('meeting_codes.xml')" />
	<xsl:key name="meetingCodes" match="meeting_group/meeting_days" use="@code" />
	
	<xsl:template match="/">
		<html>
		
			<head>
				<title>
					All Classes
				</title>
				<link href="courses.css" type="text/css" rel="stylesheet"/>
			</head>
			<body>

				<table  width="640">
					<xsl:copy-of select="document('navbarA.html')" />
					<tr> 
						<td width="200">

							<h1>
								All classes by course number
							</h1>
							
							<div class="smalltoc">
								<ul>
									<xsl:apply-templates select="//course[key('viewByCrn', @crn)]" mode="table-col1">
										<xsl:sort select="@crn" data-type="number" />
									</xsl:apply-templates>
								</ul>
							</div>
						</td>
						
						<td width="200">
							
							<div class="smalltoc">
								<ul>
									<xsl:apply-templates select="//course[key('viewByCrn', @crn)]" mode="table-col2">
										<xsl:sort select="@crn" data-type="number" />
									</xsl:apply-templates>
								</ul>
							</div>
							
							<div class="WMLbar">
								<a class="WMLbar" href="viewWML.wml">
									. WML .
								</a>
								<a class="WMLbar" href="B_viewByCrn.html">
									BASIC
								</a>
							</div>
						</td>

						<xsl:copy-of select="document('news/news.html')" />
					</tr>
				</table>

			</body>
			
			<xsl:apply-templates select="//course[key('viewByCrn', @crn)]" mode="crn">
				<xsl:sort select="@crn" data-type="number" />
			</xsl:apply-templates>				
								
		</html>
	</xsl:template>
	
	<xsl:template match="course" mode="table-col1">

		<xsl:if test="position() &gt; 0 and position() &lt; last() div 2">
			<li>
				<a class="smalltoc" href="viewByCrn/{@crn}.html">
					<xsl:value-of select="@crn"/>
					<xsl:text>  </xsl:text>
					<xsl:value-of select="title"/>
				</a>
			</li>
		</xsl:if>
		
	</xsl:template>
	
	<xsl:template match="course" mode="table-col2">

		<xsl:if test="position() &gt;= last() div 2">
			<li>
				<a class="smalltoc" href="viewByCrn/{@crn}.html">
					<xsl:value-of select="@crn"/>
					<xsl:text>  </xsl:text>
					<xsl:value-of select="title"/>
				</a>
			</li>
		</xsl:if>
		
	</xsl:template>
	
	<xsl:template match="course" mode="crn">
	
		<xsl:variable name="newPage" select="@crn"/>
		
		<xsl:document href="viewByCrn/{concat($newPage,'.html')}">
		
			<html>
				<head>
					<title>
						<xsl:value-of select="title"/>
					</title>
					<link rel="stylesheet" type="text/css" href="../courses.css"/>
				</head>
				<body>
					<div align="center">
						<table  width="640">
							<xsl:copy-of select="document('navbarB.html')" />
							<tr> 
								<td width="400" bgcolor="#ffffff">

									<h4>
										<a href="../viewByTitle.html">
											<xsl:value-of select="title"/>
										</a>
										<a class="course_gn" href="../viewByGroup.html">
											<xsl:value-of select="course_group"/>
											<xsl:text>  </xsl:text>
											<xsl:value-of select="course_num"/>
										</a>
										<a class="crn" href="../viewByCrn.html">
											(CRN: <xsl:value-of select="@crn"/>)
										</a>
									</h4>
									
									<xsl:apply-templates select="course_head/person"/>
									
									<br />
									
									<div class="day_time">
										<a href="../viewByDay.html">
										
											<!-- output the day label -->
											<xsl:variable name="mMeetingDays" select="meeting/meeting_days" />
											<!-- retrieve from external doc/key -->
											<xsl:for-each select="$meetingCodeLookup">
												<xsl:value-of select="key('meetingCodes', $mMeetingDays)/@name" />
											</xsl:for-each>
											
											<xsl:variable name="mTime" select="meeting/meeting_begin" />
											<xsl:variable name="mTimeFx" select="$mTime - 1200" />
											<xsl:choose>
												<xsl:when test="$mTime &gt; 1299">
													<xsl:choose>
														<xsl:when test="$mTimeFx &gt; 999">
															<xsl:value-of select="concat(substring($mTimeFx, 1, 2), ':', substring($mTimeFx, 3, 2))" />pm
														</xsl:when>
														<xsl:otherwise>
															<xsl:value-of select="concat(substring($mTimeFx, 1, 1), ':', substring($mTimeFx, 2, 2))" />pm
														</xsl:otherwise>
													</xsl:choose>
												</xsl:when>
												<xsl:otherwise>
													<xsl:choose>
														<xsl:when test="$mTime &gt; 999">
															<xsl:value-of select="concat(substring($mTime, 1, 2), ':', substring($mTime, 3, 2))" />am
														</xsl:when>
														<xsl:otherwise>
															<xsl:value-of select="concat(substring($mTime, 1, 1), ':', substring($mTime, 2, 2))" />am
														</xsl:otherwise>
													</xsl:choose>
												</xsl:otherwise>
											</xsl:choose>

											- <xsl:variable name="eTime"   select="meeting/meeting_end" />
											<xsl:variable name="eTimeFx" select="$eTime - 1200" />
											<xsl:choose>
												<xsl:when test="$eTime &gt; 1299">
													<xsl:choose>
														<xsl:when test="$eTimeFx &gt; 999">
															<xsl:value-of select="concat(substring($eTimeFx, 1, 2), ':', substring($eTimeFx, 3, 2))" />pm,
														</xsl:when>
														<xsl:otherwise>
															<xsl:value-of select="concat(substring($eTimeFx, 1, 1), ':', substring($eTimeFx, 2, 2))" />pm,
														</xsl:otherwise>
													</xsl:choose>
												</xsl:when>
												<xsl:otherwise>
													<xsl:choose>
														<xsl:when test="$eTime &gt; 999">
															<xsl:value-of select="concat(substring($eTime, 1, 2), ':', substring($eTime, 3, 2))" />am,
														</xsl:when>
														<xsl:otherwise>
															<xsl:value-of select="concat(substring($eTime, 1, 1), ':', substring($eTime, 2, 2))" />am,
														</xsl:otherwise>
													</xsl:choose>
												</xsl:otherwise>
											</xsl:choose>
											
										</a>
										
										<span>
											<xsl:value-of select="meeting/location"/>
										</span>
									</div>
										
									<div class="description">
										<xsl:value-of select="description"/> 
									</div>
									
									<div>
										<a href="../pdf/byCrn/{@crn}.pdf">
											<img align="right" src="../pdfdoc.gif" alt="PDF" />
										</a>
									</div>
									
								</td>
								
								<xsl:copy-of select="document('news/news.html')" />
								
							</tr>
						</table>
					</div>
			 	</body>
			 </html>
		</xsl:document>
		
	</xsl:template>
	
	<xsl:template match="person">
	
		<div class="course_head">
			<div>
				<span class="course_head_name">
					<a href="../viewByInstructor.html">
						<xsl:value-of select="person_name"/>
					</a>
					<xsl:text>   </xsl:text>
				</span>
				<span class="course_head_title">
					<xsl:value-of select="person_title"/>
				</span>
			</div>
		</div>
		
	</xsl:template>
	
</xsl:stylesheet>