<?xml version="1.0" encoding="utf-8"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.1">
	 
	<xsl:output method="xml" doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" 
		doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd" indent="yes"/>
	
	<xsl:param name="acad_year" select="'2002'"/>
	<xsl:param name="term_id" select="'3'"/>

	<!-- '$acad_year' and '$term_it' hardcoded, as saxon refuses vars passed into key -->
	<xsl:key name="viewByTitle" match="course[@acad_year=2002 and @term_id=3]" use="title"/>
	
	<!-- access external doc. -->
	<xsl:variable name="courseCodeLookup" select="document('courses_codes.xml')"/>
	<xsl:key name="courseCodes" match="course_groups/course_group" use="@code"/>
	
	<xsl:template match="/">
		<html>
		
			<head>
				<title>
					 Courses
				</title>
				<link href="courses.css" type="text/css" rel="stylesheet"/>
			</head>
			<body>

				<table  width="640">
					<xsl:copy-of select="document('navbarA.html')" />
					<tr> 
						<td width="200">
							<h1>
								Courses
							</h1>
							
							<div class="smalltoc">
								<ul>
									<xsl:apply-templates select="//course[generate-id() = generate-id(key('viewByTitle', title)[1])]" mode="table-col1">
										<xsl:sort select="title"/>
									</xsl:apply-templates>
								</ul>
							</div>
							
						</td>
						<td width="200">
							
							<div class="smalltoc">
								<ul>
									<xsl:apply-templates select="//course[generate-id() = generate-id(key('viewByTitle', title)[1])]" mode="table-col2">
										<xsl:sort select="title"/>
									</xsl:apply-templates>
								</ul>
							</div>
							
							<div class="WMLbar">
								<a class="WMLbar" href="viewWML.wml">
									. WML .
								</a>
								<a class="WMLbar" href="B_viewByTitle.html">
									BASIC
								</a>
							</div>
							
						</td>
						
						<xsl:copy-of select="document('news/news.html')" />
					</tr>
				</table>
			
			</body>
			
			<xsl:apply-templates select="//course[generate-id() = generate-id(key('viewByTitle', title)[1])]" mode="title">
				<xsl:sort select="title"/>
			</xsl:apply-templates>
			
		</html>
	</xsl:template>
	
	<xsl:template match="course" mode="table-col1">

		<xsl:if test="position() &gt; 0 and position() &lt; last() div 2">
			<li>
				<xsl:choose>
					<xsl:when test="count(key('viewByTitle', title))=1">
						<a class="smalltoc" href="viewByCrn/{@crn}.html">
							<xsl:value-of select="title" />
						</a>
					</xsl:when>
					<xsl:otherwise>
						<a class="smalltoc" href="viewByTitle/{title}.html">
							<xsl:value-of select="title" />
						</a>
					</xsl:otherwise>
				</xsl:choose>
			</li>
		</xsl:if>
		
	</xsl:template>
	
	<xsl:template match="course" mode="table-col2">

		<xsl:if test="position() &gt;= last() div 2">
			<li>
				<xsl:choose>
					<xsl:when test="count(key('viewByTitle', title))=1">
						<a class="smalltoc" href="viewByCrn/{@crn}.html">
							<xsl:value-of select="title" />
						</a>
					</xsl:when>
					<xsl:otherwise>
						<a class="smalltoc" href="viewByTitle/{title}.html">
							<xsl:value-of select="title" />
						</a>
					</xsl:otherwise>
				</xsl:choose>
			</li>
		</xsl:if>
		
	</xsl:template>
	
	<xsl:template match="course" mode="title">
	
		<xsl:if test="count(key('viewByTitle', title))!=1">
			<xsl:variable name="nHtml" select="title"/>
			
			<xsl:document href="viewByTitle/{concat($nHtml,'.html')}">
			
				<html>
					<head>
						<title>
							<xsl:value-of select="title"/>
						</title>
						<link rel="stylesheet" type="text/css" href="../courses.css"/>
					</head>
					<body>
						<div align="center">
							<table  width="640">
								<xsl:copy-of select="document('navbarB.html')" />
								<tr> 
									<td width="400" bgcolor="#ffffff">
						
										<!--
										<h1>
											<xsl:value-of select="title"/>
										</h1>
										-->
					
										<xsl:apply-templates select="key('viewByTitle', title)">
											<xsl:sort select="course_num"/>
										</xsl:apply-templates>
										
										<br /> <br /> <br />
										
										<div class="top">
										
											<hr/>
											
											<a href="../viewByTitle.html">
												Return to Course Listing
											</a>
											
											<hr/>
											
										</div>
									</td>
									<xsl:copy-of select="document('news/news.html')" />
								</tr>
							</table>
						</div>
					</body>
				</html>
			</xsl:document>
		</xsl:if>
		
	</xsl:template>
	
	
	<xsl:template match="course">
	
		<div class="course">
			<span class="title">
				<a href="../viewByCrn/{@crn}.html">
					<xsl:value-of select="title"/>
				</a>
			</span>
			<span class="course_gn">
				<xsl:value-of select="course_group"/><xsl:text>  </xsl:text><xsl:value-of select="course_num"/>.
			</span>
			<span class="crn">
				(CRN: <xsl:value-of select="@crn"/>)
			</span>
		</div>
		
		<xsl:apply-templates select="course_head/person"/>
        
	</xsl:template>
	
	<xsl:template match="person">
	
		<div class="course_head">
			<div>
				<span class="course_head_name">
					<xsl:value-of select="person_name"/>
					<xsl:text> </xsl:text>
				</span>
				<span class="course_head_title">
					<xsl:value-of select="person_title"/>
				</span>
			</div>
		</div>
		
	</xsl:template>
	
</xsl:stylesheet>