<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

	<xsl:output method="xml" doctype-public="-//PHONE.COM//DTD WML 1.3//EN" doctype-system="http://www.openwave.com/dtd/wml13.dtd"/>
	
	<!-- '$acad_year' and '$term_it' hardcoded, as saxon refuses vars passed into key -->
	<xsl:key name="viewByGroup" match="course[@acad_year=2002 and @term_id=3]" use="course_group" />
	
	<!-- access external doc. -->
	<xsl:variable name="courseCodeLookup" select="document('courses_codes.xml')" />
	<xsl:key name="courseCodes" match="course_groups/course_group" use="@code" />
	
	<xsl:template match="/">
	
		<wml>
		
			<card id="toc">
				<p>
					<strong>
						Courses by Subject
					</strong>
					
				</p>
								
				<select>
					<xsl:apply-templates select="//course[generate-id() = generate-id(key('viewByGroup', course_group)[1])]" mode="toc">
						<xsl:sort select="document('courses_codes.xml')/courses_codes/course_groups/course_group[@code = current()/course_group]/@name"/>
					</xsl:apply-templates>
				</select>
				
			</card>
			
			<xsl:apply-templates select="//course[generate-id() = generate-id(key('viewByGroup', course_group)[1])]" mode="cardGroup">
				<xsl:sort select="course_group"/>
			</xsl:apply-templates>
			
			<xsl:apply-templates select="//course[@acad_year=2002 and @term_id=3]" mode="cardCRN" />
						
		</wml>
		
	</xsl:template>
	
	
	<xsl:template match="course" mode="toc">
		<option onpick="#{course_group}">
			<!-- set var = course_group code -->
			<xsl:variable name="myCourseGroup" select="course_group" />
			
			<!-- retrieve from external doc/key -->
			<xsl:for-each select="$courseCodeLookup">
				<xsl:value-of select="key('courseCodes', $myCourseGroup)/@name" />
			</xsl:for-each>
		</option>
	</xsl:template>
	
	
	<xsl:template match="course" mode="cardGroup">
		<card id="{course_group}">
			<p>
				<strong>
					<xsl:variable name="mCourseGroup" select="course_group" />
					<!-- retrieve from external doc/key -->
					<xsl:for-each select="$courseCodeLookup">
						<xsl:value-of select="key('courseCodes', $mCourseGroup)/@name" />
					</xsl:for-each>
				</strong>
			</p>
			
			<select>
				<xsl:apply-templates select="key('viewByGroup', course_group)" mode="courseGroups">
					<xsl:sort select="title"/>
				</xsl:apply-templates>
			</select>

			<p>
				<do label="Previous" type="accept">
					<go href="#toc"/>
				</do>
			</p>
		
		</card>
	</xsl:template>
	
	
	<xsl:template match="course" mode="courseGroups">
	
		<option onpick="#{@crn}">
			<xsl:value-of select="course_group" />
			<xsl:value-of select="course_num" />.
			<xsl:value-of select="title" />
			 (CRN: <xsl:value-of select="@crn" />)
		</option>
		
	</xsl:template>
	
	
	<xsl:template match="course" mode="cardCRN">
		<card id="{@crn}">
			<p>
				<strong>
					<xsl:value-of select="course_group" />
					<xsl:value-of select="course_num" />.
					<xsl:value-of select="title" />
					 (CRN: <xsl:value-of select="@crn" />)
				</strong>
			</p>
			
			<xsl:apply-templates select="course_head/person" />
			
			<p>
				<xsl:value-of select="description" />
			</p>
			
			<p>
				<do label="Previous" type="accept">
					<go href="#{course_group}"/>
				</do>
			</p>
			
		</card>
		
	</xsl:template>
	
	
	<xsl:template match="person">
		<p>
			<xsl:value-of select="person_name" />:
			<xsl:value-of select="person_title" />
		</p>
	</xsl:template>
	
</xsl:stylesheet>